@@ -4,13 +4,12 @@
 //
 // `tokio = { version = "1", features = ["full"] }`
 
-use tokio::{fs::File, io::AsyncReadExt};
+use deta_rust::{drive, DetaClient};
 use tokio::io::AsyncWriteExt;
-use deta_rust::{DetaClient, drive};
+use tokio::{fs::File, io::AsyncReadExt};
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-
     let client = DetaClient::new("[place_your_project_key_here]");
     let drive = drive::Drive::new(&client, "sample_drive");
 
@@ -23,7 +22,10 @@ async fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     // Download file
     let mut file = File::create("some_file_2.jpg").await?;
-    let downloaded_data = drive.get_file_as_u8_vec("some_file.jpg").await?.expect("File not found");
+    let downloaded_data = drive
+        .get_file_as_u8_vec("some_file.jpg")
+        .await?
+        .expect("File not found");
     file.write_all(&downloaded_data).await?;
 
     Ok(())
